from AutoRPE.UtilsRPE.Functions import load_vault

# Getting Command line options
from optparse import OptionParser
parser = OptionParser()
parser.add_option("-v", "--vault", dest="vault", default="./vault.pkl", metavar="FILE")
parser.add_option("-n","--name",  dest="var_name", default=None)
parser.add_option("--name-contains",  dest="var_name_contains", default=None)
parser.add_option("-r","--routine",  dest="routine_name", default=None)
parser.add_option("-m","--module",  dest="module_name", default=None)
(options, args) = parser.parse_args()

vault_path = options.vault
var_name = options.var_name
var_name_contains = options.var_name_contains
routine_name = options.routine_name
module_name = options.module_name

# Loading vault (source database)
vault = load_vault(vault_path)


# Load all the variables in the vault and start filtering by the command line parameters provided.
variables = [v for v in vault.variables if v.type in ["real", "rpe_var"]]
# Sort by id
#variables = list(sorted(variables, key=lambda x: x.id))

# Filter by exact name coincidence
if var_name is not None:
   variables = [ v for v in variables if v.name == var_name ]

# Filter by name contains
if var_name_contains is not None:
   variables = [ v for v in variables if v.name.count(var_name_contains) ]
 
# Filter by routine name coincidence
if routine_name is not None:
   variables = [ v for v in variables if v.routine.name == routine_name ]

# Filter by module name coincidence
if module_name is not None:
   variables = [ v for v in variables if v.routine.module.name == module_name ]


if len(variables) == 0:
   print("No results found")
   exit(0)

print("#%5s     %20s %25s %20s\n%s\n" %( "ID","variable","routine","module", 100*"#") )
line_format = "%5i    # %20s %25s %20s"
for v in variables:
   if v.id is not None:
      print( line_format % (v.id, v.name, v.routine.name, v.routine.module.name), "\tPrecision:", v.precision )
   else:
      print( line_format % (-1, v.name, v.routine.name, v.routine.module.name), "\tPrecision:", v.precision )
